Introduction — Ibid v0.1.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Ibid v0.1.1 documentation »

# Introduction

This is the documentation for Ibid. Ibid is a multi-protocol general purpose chat bot written in Python. It uses a natural language interface, and can connect to multiple sources including IRC, Jabber and SILC servers, as well as allowing interaction using SMTP, HTTP and various RPC protocols. It aims to be a useful base to build any kind of chat bot from, and to make plugins and extensions as easy as possible to write.

Ibid is in constant development. The code is hosted on Launchpad.

The most recent version of this documentation is available at http://ibid.omnia.za.net/docs/.

## Getting Help with Ibid

- The Ibid Developers can be found in `#ibid` on `irc.atrum.org`.
- Alternatively, file a Question on Launchpad.

### Navigation

- index
- modules |
- next |
- previous |
- Ibid v0.1.1 documentation »